bl_info={
    "name": "Tavolino",
    "author": "Alek Mugnozzo <mugnozzo@protonmail.com>",
    "version": (1, 0),
    "blender": (2, 93, 0),
    "location": "View3D > Add > Mesh",
    "description": "Operatore per aggiungere un tavolino alla scena.",
    "category": "Mesh",
}

import bpy
from math import pi

class MESH_OT_tavolino(bpy.types.Operator):
    """Aggiunge un tavolino alla scena"""
    bl_idname = "mesh.primitive_tavolino_add"
    bl_label = "Tavolino"
    bl_options = {'REGISTER', 'UNDO'}

    lar: bpy.props.FloatProperty(
        name="Larghezza",
        description="Larghezza della tavola",
        default=2,
        unit='LENGTH',
        min=.8,
        soft_max=20,
        precision=4,
    )
    lun: bpy.props.FloatProperty(
        name="Lunghezza",
        description="Lunghezza della tavola",
        default=.8,
        unit='LENGTH',
        min=.8,
        soft_max=20,
    )
    spe: bpy.props.FloatProperty(
        name="Spessore",
        description="Spessore della tavola",
        default=.05,
        unit='LENGTH',
        min=.01,
        max=.1,
    )
    alt: bpy.props.FloatProperty(
        name="Altezza",
        description="Altezza delle gambe",
        default=.7,
        unit='LENGTH',
        min=.6,
    )
    dia: bpy.props.FloatProperty(
        name="Diametro",
        description="Diametro della singola gamba",
        default=.05,
        unit='LENGTH',
        min=.04,
        max=.1,
    )
    gap: bpy.props.FloatProperty(
        name="Gap Gambo-Tavolo",
        description="Distanza tra bordo della gamba e bordo della tavola",
        default=.05,
        unit='LENGTH',
        min=0,
        max=.1,
    )
    loc: bpy.props.FloatVectorProperty(
        name="Posizione",
        description="Coordinate del centro della tavola",
        default=(0,0),
        size=2,
        unit='LENGTH',
    )
    rot: bpy.props.FloatProperty(
        name="Rotazione",
        description="Rotazione della tavola sull'asse Z",
        default=0,
        unit='ROTATION',
    )
    
    @classmethod
    def poll(cls,context):
        return context.mode=="OBJECT"
    
    def execute(self,context):
        print(context.area.type)
        lar=self.lar
        lun=self.lun
        spe=self.spe
        alt=self.alt
        dia=self.dia
        gap=self.gap
        loc=self.loc
        rot=self.rot
        bpy.ops.mesh.primitive_cube_add(size=1,location=(loc[0],loc[1],alt+spe/2),scale=(lar,lun,spe),rotation=(0,0,rot))
        tavola=bpy.context.object
        loc_x=lar/2-dia/2-gap
        loc_y=lun/2-dia/2-gap
        bpy.ops.mesh.primitive_cylinder_add(vertices=64,radius=dia/2,depth=alt,location=(loc_x,loc_y,-alt/2-spe/2))
        gambo1=bpy.context.object
        gambo1.parent=tavola
        bpy.ops.mesh.primitive_cylinder_add(vertices=64,radius=dia/2,depth=alt,location=(loc_x,-loc_y,-alt/2-spe/2))
        gambo2=bpy.context.object
        gambo2.parent=tavola
        bpy.ops.mesh.primitive_cylinder_add(vertices=64,radius=dia/2,depth=alt,location=(-loc_x,loc_y,-alt/2-spe/2))
        gambo3=bpy.context.object
        gambo3.parent=tavola
        bpy.ops.mesh.primitive_cylinder_add(vertices=64,radius=dia/2,depth=alt,location=(-loc_x,-loc_y,-alt/2-spe/2))
        gambo4=bpy.context.object
        gambo4.parent=tavola
        return {'FINISHED'}

def menu_draw(self,context):
    self.layout.operator("mesh.primitive_tavolino_add")

def register():
    bpy.types.VIEW3D_MT_mesh_add.append(menu_draw)
    bpy.utils.register_class(MESH_OT_tavolino)

def unregister():
    bpy.types.VIEW3D_MT_mesh_add.remove(menu_draw)
    bpy.utils.unregister_class(MESH_OT_tavolino)
